Models
-------------

.. autopydantic_model:: aind_watchdog_service.models.manifest_config.ManifestConfig
    :members:
    :undoc-members:
    :show-inheritance:


.. autopydantic_model:: aind_watchdog_service.models.watch_config.WatchConfig
    :members:
    :undoc-members:
    :show-inheritance:


